@@ -5,11 +5,13 @@
 # and average)
 # S. Borrett | July 2011
 # ---------------------------------------------------
-eigenCentrality <- function(x){
+eigenCentrality <- function(x='matrix'){
   if (class(x) != 'matrix'){warning('x is not a matrix class object')}
-  EVCin <- abs(eigen(x)$vectors[,1])  # find dominant eigenvector of x
+                                        # find dominant eigenvector of x
+  EVCin <- abs(eigen(x)$vectors[,1])
   EVCin <- EVCin/sum(EVCin)           # normalize by sum
-  EVCout <- abs(eigen(t(x))$vectors[,1])  # find dominant eigenvector of x transpose
+                                        # find dominant eigenvector of x transpose
+  EVCout <- abs(eigen(t(x))$vectors[,1])  
   EVCout <- EVCout/sum(EVCout)        # normalize by sum  
   AEVC <- (EVCin + EVCout)/2          # find average eigenvector centrality
   
