@@ -6,19 +6,15 @@
 # S. Borrett and M. Lau | March 2011
 # ---------------------------------------------------
 
-enaStructure <- function(x = 'network object',balance.override=FALSE){
+enaStructure <- function(x = 'network object'){
                                         #Check for network class
   if (class(x) != 'network'){warning('x is not a network class object')}
-                                        #Check for balancing
-  if (balance.override == TRUE){}else{
-    if (any(list.network.attributes(x) == 'balanced') == FALSE){x%n%'balanced' <- ssCheck(x)}
-    if (x%n%'balanced' == FALSE){warning('Model is not balanced'); stop}
-  }
-  
-  F <- t(x%n%'flow')
+  F <- t(x%n%'flow') #get flows
   A <- sign(F)   # get adjacency matrix
   sp <- structure.statistics(A)    # calls structure.statistics helper function
-  
+                                          #Output orientation
+  orient <- get.orient()
+  if (orient=='rc'){A <- t(A)}else{}
   return(list('A'=A,'ns'=sp))  # "A" is the adjacency matrix oriented
                                         # column to row and "sp" is a list of
                                         # structural network staistics
